@@ -28,17 +28,24 @@ use Moose;
 
 with 'Net::ISC::DHCPd::Config::Role';
 
-__PACKAGE__->create_children(qw/
-    Net::ISC::DHCPd::Config::Subnet
-    Net::ISC::DHCPd::Config::Subnet6
-    Net::ISC::DHCPd::Config::SharedNetwork
-    Net::ISC::DHCPd::Config::Group
-    Net::ISC::DHCPd::Config::Host
-    Net::ISC::DHCPd::Config::Option
-    Net::ISC::DHCPd::Config::KeyValue
-/);
+=head2 children
 
+See L<Net::ISC::DHCPd::Config::Role/children>.
 
+=cut
+sub children {
+    return qw/
+        Net::ISC::DHCPd::Config::Subnet
+        Net::ISC::DHCPd::Config::Subnet6
+        Net::ISC::DHCPd::Config::SharedNetwork
+        Net::ISC::DHCPd::Config::Group
+        Net::ISC::DHCPd::Config::Host
+        Net::ISC::DHCPd::Config::Option
+        Net::ISC::DHCPd::Config::KeyValue
+    /;
+}
+
+__PACKAGE__->create_children(__PACKAGE__->children());
 =head1 ATTRIBUTES
 
 =head2 type
@@ -59,7 +66,12 @@ has logic => (
     isa => 'Str',
 );
 
-sub _build_regex { qr/^ \s* (if|elsif|else) (.*?)(\s+\{|$) /x }
+=head2 regex
+
+See L<Net::ISC::DHCPd::Config::Role/regex>.
+
+=cut
+sub regex { qr/^ \s* (if|elsif|else) (.*?)(\s+\{|$) /x }
 
 =head1 METHODS
 
@@ -70,7 +82,7 @@ See L<Net::ISC::DHCPd::Config::Role/captured_to_args>.
 =cut
 
 sub captured_to_args {
-    my($self, $type, $logic) = @_;
+    my($type, $logic) = @_;
 
     $logic =~ s/^\s+|\s+$//g;
 
