@@ -29,24 +29,38 @@ use Path::Class::File;
 
 with 'Net::ISC::DHCPd::Config::Root';
 
-__PACKAGE__->create_children(qw/
-    Net::ISC::DHCPd::Config::Conditional
-    Net::ISC::DHCPd::Config::Class
-    Net::ISC::DHCPd::Config::SubClass
-    Net::ISC::DHCPd::Config::Host
-    Net::ISC::DHCPd::Config::Subnet
-    Net::ISC::DHCPd::Config::Subnet6
-    Net::ISC::DHCPd::Config::SharedNetwork
-    Net::ISC::DHCPd::Config::Function
-    Net::ISC::DHCPd::Config::OptionSpace
-    Net::ISC::DHCPd::Config::OptionCode
-    Net::ISC::DHCPd::Config::Option
-    Net::ISC::DHCPd::Config::Key
-    Net::ISC::DHCPd::Config::Zone
-    Net::ISC::DHCPd::Config::Group
-    Net::ISC::DHCPd::Config::Block
-    Net::ISC::DHCPd::Config::KeyValue
-/);
+=head2 children
+
+See L<Net::ISC::DHCPd::Config::Role/children>.
+
+=cut
+
+sub children {
+
+    return qw/
+        Net::ISC::DHCPd::Config::Authoritative
+        Net::ISC::DHCPd::Config::Include
+        Net::ISC::DHCPd::Config::Conditional
+        Net::ISC::DHCPd::Config::FailoverPeer
+        Net::ISC::DHCPd::Config::Class
+        Net::ISC::DHCPd::Config::SubClass
+        Net::ISC::DHCPd::Config::Host
+        Net::ISC::DHCPd::Config::Subnet
+        Net::ISC::DHCPd::Config::Subnet6
+        Net::ISC::DHCPd::Config::SharedNetwork
+        Net::ISC::DHCPd::Config::Function
+        Net::ISC::DHCPd::Config::OptionSpace
+        Net::ISC::DHCPd::Config::OptionCode
+        Net::ISC::DHCPd::Config::Option
+        Net::ISC::DHCPd::Config::Key
+        Net::ISC::DHCPd::Config::Zone
+        Net::ISC::DHCPd::Config::Group
+        Net::ISC::DHCPd::Config::Block
+        Net::ISC::DHCPd::Config::KeyValue
+    /;
+}
+
+__PACKAGE__->create_children(__PACKAGE__->children());
 
 =head1 ATTRIBUTES
 
@@ -71,15 +85,25 @@ has generate_with_include => (
     default => 0,
 );
 
-sub _build_regex { qr{^\s* include \s+ "([^"]+)" ;}x }
+=head2 regex
+
+See L<Net::ISC::DHCPd::Config::Role/regex>.
+
+=cut
+sub regex { qr{^\s* include \s+ "([^"]+)" ;}x }
 sub _build_root { shift->parent }
 
 sub _build__filehandle {
     my $self = shift;
     my $file = $self->file;
 
+    if ($self->filename_callback) {
+        $file = Path::Class::File->new(&{$self->filename_callback}($file));
+    }
+
     if($file->is_relative and !-e $file) {
         $file = Path::Class::File->new($self->root->file->dir, $file);
+        $self->file($file);  # needed so dir stays updated with recursive includes
     }
 
     return $file->openr;
@@ -118,7 +142,7 @@ See L<Net::ISC::DHCPd::Config::Role/captured_to_args>.
 =cut
 
 sub captured_to_args {
-    return { file => $_[1] };
+    return { file => $_[0] };
 }
 
 =head2 generate
