@@ -45,8 +45,23 @@ has [qw/ name algorithm secret /] => (
     isa => 'Str',
 );
 
-sub _build_children { [undef] }
-sub _build_regex { qr{^\s* key \s+ ("?)(\S+)(\1) }x }
+=head2 regex
+
+See L<Net::ISC::DHCPd::Config::Role/regex>.
+
+=cut
+
+sub regex { qr{^\s* key \s+ ("?)(\S+)(\1) }x }
+
+=head2 children
+
+Modules with slurp need this special children variable to trick the parser
+into recursively processing them.
+
+=cut
+
+sub children { [undef] }
+
 
 =head1 METHODS
 
@@ -74,7 +89,7 @@ See L<Net::ISC::DHCPd::Config::Role/captured_to_args>.
 =cut
 
 sub captured_to_args {
-    return { name => $_[2] }; # $_[1] == quote or empty string
+    return { name => $_[1] }; # $_[0] == quote or empty string
 }
 
 =head2 generate
@@ -90,7 +105,7 @@ sub generate {
         sprintf('key "%s" {', $self->name),
         $self->algorithm ? (sprintf '    algorithm %s;', $self->algorithm) : (),
         $self->secret ? (sprintf '    secret "%s";', $self->secret) : (),
-        '};', # TODO: should this really be here?
+        '};', # semicolon is for compatibility with bind key files
     );
 }
 
