@@ -60,7 +60,13 @@ has quoted => (
     isa => 'Bool',
 );
 
-sub _build_regex { qr{^\s* option \s+ (\S+) \s+ (.*) ;}x }
+=head2 regex
+
+See L<Net::ISC::DHCPd::Config::Role/regex>.
+
+=cut
+
+sub regex { qr{^\s* option \s+ (\S+) \s+ (.*) ;}x }
 
 =head1 METHODS
 
@@ -71,7 +77,6 @@ See L<Net::ISC::DHCPd::Config::Role/captured_to_args>.
 =cut
 
 sub captured_to_args {
-    my $self   = shift;
     my $name   = shift;
     my $value  = shift;
     my $quoted = 0;
