@@ -45,9 +45,24 @@ has [qw/ name key primary /] => (
     isa => 'Str',
 );
 
-sub _build_children { [undef] }
+=head2 regex
+
+See L<Net::ISC::DHCPd::Config::Role/regex>.
+
+=cut
+
 # not sure if this can be quoted or not
-sub _build_regex { qr{^\s* zone \s+ (")?(\S+)(\1|$) }x }
+sub regex { qr{^\s* zone \s+ (")?(\S+)(\1|$) }x }
+
+=head2 children
+
+Modules with slurp need this special children variable to trick the parser
+into recursively processing them.
+
+=cut
+
+sub children { [undef] }
+
 
 =head1 METHODS
 
@@ -76,7 +91,7 @@ See L<Net::ISC::DHCPd::Config::Role/captured_to_args>.
 =cut
 
 sub captured_to_args {
-    return { name => $_[2] }; # $_[1] == quote or empty string
+    return { name => $_[1] }; # $_[0] == quote or empty string
 }
 
 =head2 generate
@@ -92,7 +107,7 @@ sub generate {
         sprintf('zone %s {', $self->name),
         $self->primary ? (sprintf '    primary %s;', $self->primary) : (),
         $self->key ? (sprintf '    key %s;', $self->key) : (),
-        '}', # TODO: should this really be here?
+        '}',
     );
 }
 
